@@ -1,22 +1,21 @@
 
-import simplejson 
+import simplejson
 
 from tiddlyweb.serializer import Serializer
 from tiddlyweb.model.tiddler import Tiddler
 from tiddlyweb.model.bag import Bag
 
-from tiddlywebplugins.utils import get_store
 from tiddlyweb.config import config
 
+from .fixtures import get_store
 
-def setup_module(module):
-    module.store = get_store(config)
 
 def test_json_perms():
+    store = get_store(config)
     bag = Bag('permstest')
     store.put(bag)
     serializer = Serializer('json', environ={'tiddlyweb.usersign': {
-        'name':'bang', 'roles': []}, 'tiddlyweb.config': config})
+        'name': 'bang', 'roles': []}, 'tiddlyweb.config': config})
     tiddler = Tiddler('permstest', 'permstest')
     tiddler.text = 'permstest'
     store.put(tiddler)
