@@ -1,6 +1,6 @@
 """
 Make sure that tiddler fields which are not strings
-are stringified, otherwise, the text serialization will 
+are stringified, otherwise, the text serialization will
 assplode.
 """
 
@@ -8,10 +8,6 @@ from tiddlyweb.serializer import Serializer
 from tiddlyweb.model.tiddler import Tiddler
 
 
-def setup_module(module):
-    pass
-
-
 def test_float_field():
     tiddler = Tiddler('foo', 'bar')
     tiddler.fields['float'] = 100.5
