@@ -31,7 +31,10 @@ When doing sorting ``ATTRIBUTE_SORT_KEY`` is consulted to canonicalize the
 value. See :py:mod:`tiddlyweb.filters.sort`.
 """
 
-from itertools import ifilter
+try:
+    from itertools import ifilter as filter
+except ImportError:  # Python3 has built in filter that iterates
+    pass
 from operator import gt, lt
 
 from tiddlyweb.filters.sort import ATTRIBUTE_SORT_KEY
@@ -124,7 +127,7 @@ def text_in_text(entity, attribute, value):
     """
     try:
         return value.lower() in entity.text.lower()
-    except UnicodeDecodeError:
+    except (UnicodeDecodeError, TypeError):
         # Binary tiddler
         return False
 
@@ -192,7 +195,7 @@ def select_by_attribute(attribute, value, entities, negate=False,
         else:
             _filter = _posfilter
 
-        return ifilter(_filter, entities)
+        return filter(_filter, entities)
 
 
 def select_relative_attribute(attribute, value, entities,
@@ -235,4 +238,4 @@ def select_relative_attribute(attribute, value, entities,
             return comparator(func(getattr(stored_entity, attribute, None)),
                     func(value))
 
-    return ifilter(_select, entities)
+    return filter(_select, entities)
